# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/assistant/assistant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/assistant/assistant.proto',
  package='sensory.api.v1.assistant',
  syntax='proto3',
  serialized_options=b'\n ai.sensorycloud.api.v1.assistantB\032SensoryApiV1AssistantProtoP\001Z>gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/assistant',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cv1/assistant/assistant.proto\x12\x18sensory.api.v1.assistant\x1a\x17validate/validate.proto\"\x93\x02\n\x17\x41ssistantMessageRequest\x12\x42\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x30.sensory.api.v1.assistant.AssistantMessageConfigH\x00\x12=\n\x07message\x18\x02 \x01(\x0b\x32*.sensory.api.v1.assistant.AssistantMessageH\x00\x12\\\n\x14postProcessingAction\x18\n \x01(\x0b\x32>.sensory.api.v1.assistant.AssistantPostProcessingActionRequestB\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"V\n\x10\x41ssistantMessage\x12\x1a\n\x04text\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x0fH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x0e\n\x07message\x12\x03\xf8\x42\x01\"*\n\x06Intent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"\x9b\x02\n\x18\x41ssistantMessageResponse\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x14\n\x0c\x61udioContent\x18\x02 \x01(\x0c\x12\x30\n\x06intent\x18\x03 \x01(\x0b\x32 .sensory.api.v1.assistant.Intent\x12\x31\n\x07intents\x18\x04 \x03(\x0b\x32 .sensory.api.v1.assistant.Intent\x12\x17\n\x0fisAudioComplete\x18\x05 \x01(\x08\x12]\n\x14postProcessingAction\x18\n \x01(\x0b\x32?.sensory.api.v1.assistant.AssistantPostProcessingActionResponse\"\x8d\x01\n\x16\x41ssistantMessageConfig\x12\x19\n\x06userId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1b\n\x08\x64\x65viceId\x18\x03 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1d\n\tmodelName\x18\x04 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1c\n\x14includeAudioResponse\x18\x05 \x01(\x08\"\x8b\x01\n$AssistantPostProcessingActionRequest\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x37.sensory.api.v1.assistant.AssistantPostProcessingActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\x8c\x01\n%AssistantPostProcessingActionResponse\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x37.sensory.api.v1.assistant.AssistantPostProcessingActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01*7\n\x1d\x41ssistantPostProcessingAction\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05\x46INAL\x10\x01\x32\x91\x01\n\x10\x41ssistantService\x12}\n\x0eProcessMessage\x12\x31.sensory.api.v1.assistant.AssistantMessageRequest\x1a\x32.sensory.api.v1.assistant.AssistantMessageResponse\"\x00(\x01\x30\x01\x42\x80\x01\n ai.sensorycloud.api.v1.assistantB\x1aSensoryApiV1AssistantProtoP\x01Z>gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/assistantb\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,])

_ASSISTANTPOSTPROCESSINGACTION = _descriptor.EnumDescriptor(
  name='AssistantPostProcessingAction',
  full_name='sensory.api.v1.assistant.AssistantPostProcessingAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1208,
  serialized_end=1263,
)
_sym_db.RegisterEnumDescriptor(_ASSISTANTPOSTPROCESSINGACTION)

AssistantPostProcessingAction = enum_type_wrapper.EnumTypeWrapper(_ASSISTANTPOSTPROCESSINGACTION)
NOT_SET = 0
FINAL = 1



_ASSISTANTMESSAGEREQUEST = _descriptor.Descriptor(
  name='AssistantMessageRequest',
  full_name='sensory.api.v1.assistant.AssistantMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.assistant.AssistantMessageRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='sensory.api.v1.assistant.AssistantMessageRequest.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.assistant.AssistantMessageRequest.postProcessingAction', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.assistant.AssistantMessageRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=84,
  serialized_end=359,
)


_ASSISTANTMESSAGE = _descriptor.Descriptor(
  name='AssistantMessage',
  full_name='sensory.api.v1.assistant.AssistantMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='sensory.api.v1.assistant.AssistantMessage.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\017', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.assistant.AssistantMessage.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='sensory.api.v1.assistant.AssistantMessage.message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=361,
  serialized_end=447,
)


_INTENT = _descriptor.Descriptor(
  name='Intent',
  full_name='sensory.api.v1.assistant.Intent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.assistant.Intent.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='sensory.api.v1.assistant.Intent.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=491,
)


_ASSISTANTMESSAGERESPONSE = _descriptor.Descriptor(
  name='AssistantMessageResponse',
  full_name='sensory.api.v1.assistant.AssistantMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='sensory.api.v1.assistant.AssistantMessageResponse.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.assistant.AssistantMessageResponse.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intent', full_name='sensory.api.v1.assistant.AssistantMessageResponse.intent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intents', full_name='sensory.api.v1.assistant.AssistantMessageResponse.intents', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isAudioComplete', full_name='sensory.api.v1.assistant.AssistantMessageResponse.isAudioComplete', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.assistant.AssistantMessageResponse.postProcessingAction', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=777,
)


_ASSISTANTMESSAGECONFIG = _descriptor.Descriptor(
  name='AssistantMessageConfig',
  full_name='sensory.api.v1.assistant.AssistantMessageConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.assistant.AssistantMessageConfig.userId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='sensory.api.v1.assistant.AssistantMessageConfig.deviceId', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.assistant.AssistantMessageConfig.modelName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeAudioResponse', full_name='sensory.api.v1.assistant.AssistantMessageConfig.includeAudioResponse', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=921,
)


_ASSISTANTPOSTPROCESSINGACTIONREQUEST = _descriptor.Descriptor(
  name='AssistantPostProcessingActionRequest',
  full_name='sensory.api.v1.assistant.AssistantPostProcessingActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionId', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionRequest.actionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionRequest.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1063,
)


_ASSISTANTPOSTPROCESSINGACTIONRESPONSE = _descriptor.Descriptor(
  name='AssistantPostProcessingActionResponse',
  full_name='sensory.api.v1.assistant.AssistantPostProcessingActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionId', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionResponse.actionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionResponse.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1206,
)

_ASSISTANTMESSAGEREQUEST.fields_by_name['config'].message_type = _ASSISTANTMESSAGECONFIG
_ASSISTANTMESSAGEREQUEST.fields_by_name['message'].message_type = _ASSISTANTMESSAGE
_ASSISTANTMESSAGEREQUEST.fields_by_name['postProcessingAction'].message_type = _ASSISTANTPOSTPROCESSINGACTIONREQUEST
_ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _ASSISTANTMESSAGEREQUEST.fields_by_name['config'])
_ASSISTANTMESSAGEREQUEST.fields_by_name['config'].containing_oneof = _ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest']
_ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _ASSISTANTMESSAGEREQUEST.fields_by_name['message'])
_ASSISTANTMESSAGEREQUEST.fields_by_name['message'].containing_oneof = _ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest']
_ASSISTANTMESSAGE.oneofs_by_name['message'].fields.append(
  _ASSISTANTMESSAGE.fields_by_name['text'])
_ASSISTANTMESSAGE.fields_by_name['text'].containing_oneof = _ASSISTANTMESSAGE.oneofs_by_name['message']
_ASSISTANTMESSAGE.oneofs_by_name['message'].fields.append(
  _ASSISTANTMESSAGE.fields_by_name['audioContent'])
_ASSISTANTMESSAGE.fields_by_name['audioContent'].containing_oneof = _ASSISTANTMESSAGE.oneofs_by_name['message']
_ASSISTANTMESSAGERESPONSE.fields_by_name['intent'].message_type = _INTENT
_ASSISTANTMESSAGERESPONSE.fields_by_name['intents'].message_type = _INTENT
_ASSISTANTMESSAGERESPONSE.fields_by_name['postProcessingAction'].message_type = _ASSISTANTPOSTPROCESSINGACTIONRESPONSE
_ASSISTANTPOSTPROCESSINGACTIONREQUEST.fields_by_name['action'].enum_type = _ASSISTANTPOSTPROCESSINGACTION
_ASSISTANTPOSTPROCESSINGACTIONRESPONSE.fields_by_name['action'].enum_type = _ASSISTANTPOSTPROCESSINGACTION
DESCRIPTOR.message_types_by_name['AssistantMessageRequest'] = _ASSISTANTMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['AssistantMessage'] = _ASSISTANTMESSAGE
DESCRIPTOR.message_types_by_name['Intent'] = _INTENT
DESCRIPTOR.message_types_by_name['AssistantMessageResponse'] = _ASSISTANTMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['AssistantMessageConfig'] = _ASSISTANTMESSAGECONFIG
DESCRIPTOR.message_types_by_name['AssistantPostProcessingActionRequest'] = _ASSISTANTPOSTPROCESSINGACTIONREQUEST
DESCRIPTOR.message_types_by_name['AssistantPostProcessingActionResponse'] = _ASSISTANTPOSTPROCESSINGACTIONRESPONSE
DESCRIPTOR.enum_types_by_name['AssistantPostProcessingAction'] = _ASSISTANTPOSTPROCESSINGACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AssistantMessageRequest = _reflection.GeneratedProtocolMessageType('AssistantMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGEREQUEST,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessageRequest)
  })
_sym_db.RegisterMessage(AssistantMessageRequest)

AssistantMessage = _reflection.GeneratedProtocolMessageType('AssistantMessage', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGE,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessage)
  })
_sym_db.RegisterMessage(AssistantMessage)

Intent = _reflection.GeneratedProtocolMessageType('Intent', (_message.Message,), {
  'DESCRIPTOR' : _INTENT,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.Intent)
  })
_sym_db.RegisterMessage(Intent)

AssistantMessageResponse = _reflection.GeneratedProtocolMessageType('AssistantMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGERESPONSE,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessageResponse)
  })
_sym_db.RegisterMessage(AssistantMessageResponse)

AssistantMessageConfig = _reflection.GeneratedProtocolMessageType('AssistantMessageConfig', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGECONFIG,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessageConfig)
  })
_sym_db.RegisterMessage(AssistantMessageConfig)

AssistantPostProcessingActionRequest = _reflection.GeneratedProtocolMessageType('AssistantPostProcessingActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTPOSTPROCESSINGACTIONREQUEST,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantPostProcessingActionRequest)
  })
_sym_db.RegisterMessage(AssistantPostProcessingActionRequest)

AssistantPostProcessingActionResponse = _reflection.GeneratedProtocolMessageType('AssistantPostProcessingActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTPOSTPROCESSINGACTIONRESPONSE,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantPostProcessingActionResponse)
  })
_sym_db.RegisterMessage(AssistantPostProcessingActionResponse)


DESCRIPTOR._options = None
_ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest']._options = None
_ASSISTANTMESSAGE.oneofs_by_name['message']._options = None
_ASSISTANTMESSAGE.fields_by_name['text']._options = None
_ASSISTANTMESSAGECONFIG.fields_by_name['userId']._options = None
_ASSISTANTMESSAGECONFIG.fields_by_name['deviceId']._options = None
_ASSISTANTMESSAGECONFIG.fields_by_name['modelName']._options = None
_ASSISTANTPOSTPROCESSINGACTIONREQUEST.fields_by_name['action']._options = None
_ASSISTANTPOSTPROCESSINGACTIONRESPONSE.fields_by_name['action']._options = None

_ASSISTANTSERVICE = _descriptor.ServiceDescriptor(
  name='AssistantService',
  full_name='sensory.api.v1.assistant.AssistantService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1266,
  serialized_end=1411,
  methods=[
  _descriptor.MethodDescriptor(
    name='ProcessMessage',
    full_name='sensory.api.v1.assistant.AssistantService.ProcessMessage',
    index=0,
    containing_service=None,
    input_type=_ASSISTANTMESSAGEREQUEST,
    output_type=_ASSISTANTMESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASSISTANTSERVICE)

DESCRIPTOR.services_by_name['AssistantService'] = _ASSISTANTSERVICE

# @@protoc_insertion_point(module_scope)



import unittest
from unittest.mock import MagicMock

from sensory_cloud.config import Config, CloudHost
from sensory_cloud.token_manager import ITokenManager, TokenManager
from sensory_cloud.services.oauth_service import ISecureCredentialStore, OauthService
from sensory_cloud.services.assistant_service import AssistantService

import sensory_cloud.generated.v1.assistant.assistant_pb2 as assistant_pb2
import sensory_cloud.generated.v1.assistant.assistant_pb2_grpc as assistant_pb2_grpc


class MockCredentialStore(ISecureCredentialStore):
    def __init__(self, client_id, client_secret):
        self._client_id = client_id
        self._client_secret = client_secret

    @property
    def client_id(self):
        return self._client_id

    @property
    def client_secret(self):
        return self._client_secret


class MockAssistantService(AssistantService):
    def __init__(
        self,
        config: Config,
        token_manager: ITokenManager,
        assistant_service_client: assistant_pb2_grpc.AssistantServiceStub,
    ):
        self.config: Config = config
        self._token_manager: ITokenManager = token_manager
        self._assistant_service_client: assistant_pb2_grpc.AssistantServiceStub = (
            assistant_service_client
        )


class AssistantServiceTest(unittest.TestCase):
    cloud_host: CloudHost = CloudHost(host="domain.name")
    config: Config = Config(cloud_host=cloud_host, tenant_id="tenant-id")
    config.connect()

    credential_store: MockCredentialStore = MockCredentialStore(
        client_id="client-id", client_secret="client-secret"
    )
    oauth_service: OauthService = OauthService(
        config=config, secure_credential_store=credential_store
    )
    token_manager: TokenManager = TokenManager(oauth_service=oauth_service)
    token_manager.get_authorization_metadata = MagicMock(return_value=None)

    assistant_service_client: assistant_pb2_grpc.AssistantServiceStub = (
        assistant_pb2_grpc.AssistantServiceStub(channel=config.channel)
    )

    def test_process_message(self):
        self.config.connect()

        user_id: str = "user-id"
        device_id: str = "device-id"
        model_name: str = "my-model"
        include_audio_response: bool = False

        assistant_message_config: assistant_pb2.AssistantMessageConfig = (
            assistant_pb2.AssistantMessageConfig(
                userId=user_id,
                deviceId=device_id,
                modelName=model_name,
                includeAudioResponse=include_audio_response,
            )
        )

        mock_request: assistant_pb2.AssistantMessageRequest = (
            assistant_pb2.AssistantMessageRequest(config=assistant_message_config)
        )
        mock_response: assistant_pb2.AssistantMessageResponse = (
            assistant_pb2.AssistantMessageResponse()
        )
        self.assistant_service_client.ProcessMessage = MagicMock(
            return_value=(mock_request, mock_response)
        )

        assistant_service: MockAssistantService = MockAssistantService(
            config=self.config,
            token_manager=self.token_manager,
            assistant_service_client=self.assistant_service_client,
        )

        (
            process_message_request,
            process_message_response,
        ) = assistant_service.process_message(
            user_id=user_id,
            device_id=device_id,
            model_name=model_name,
            include_audio_response=include_audio_response,
            message_iterator=None,
        )

        self.assertIsNotNone(process_message_response)

        config_message = process_message_request.config

        self.assertEqual(
            config_message.userId, user_id, "User ID should match what was passed in"
        )
        self.assertEqual(
            config_message.deviceId,
            device_id,
            "Device ID should match what was passed in",
        )
        self.assertEqual(
            config_message.modelName,
            model_name,
            "Model name should match what was passed in",
        )
        self.assertEqual(
            config_message.includeAudioResponse,
            include_audio_response,
            "Include audio response should match what was passed in",
        )

        self.config.channel.close()


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oauth/oauth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2
from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oauth/oauth.proto',
  package='sensory.api.oauth',
  syntax='proto3',
  serialized_options=b'\n\031ai.sensorycloud.api.oauthB\024SensoryApiOauthProtoP\001Z7gitlab.com/sensory-cloud/server/titan.git/pkg/api/oauth',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11oauth/oauth.proto\x12\x11sensory.api.oauth\x1a\x17validate/validate.proto\x1a\x13\x63ommon/common.proto\":\n\x0cTokenRequest\x12\x1a\n\x08\x63lientId\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\xdf\x01\n\x10SignTokenRequest\x12\x1a\n\x07subject\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12G\n\x05scope\x18\x02 \x01(\x0e\x32..sensory.api.oauth.SignTokenRequest.TokenScopeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"f\n\nTokenScope\x12\x08\n\x04USER\x10\x00\x12\x0f\n\x0bSUPER_ADMIN\x10\x01\x12\x11\n\rBILLING_ADMIN\x10\x02\x12\x13\n\x0fREAD_ONLY_ADMIN\x10\x03\x12\x15\n\x11\x45MAIL_SELF_VERIFY\x10\x04\"\x0f\n\rWhoAmIRequest\"4\n\x0eWhoAmIResponse\x12\x10\n\x08\x63lientId\x18\x01 \x01(\t\x12\x10\n\x08tenantId\x18\x02 \x01(\t\"+\n\x10PublicKeyRequest\x12\x17\n\x05keyId\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\"T\n\x11PublicKeyResponse\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12,\n\x07keyType\x18\x02 \x01(\x0e\x32\x1b.sensory.api.common.KeyType2\xe8\x02\n\x0cOauthService\x12P\n\x08GetToken\x12\x1f.sensory.api.oauth.TokenRequest\x1a!.sensory.api.common.TokenResponse\"\x00\x12U\n\tSignToken\x12#.sensory.api.oauth.SignTokenRequest\x1a!.sensory.api.common.TokenResponse\"\x00\x12R\n\tGetWhoAmI\x12 .sensory.api.oauth.WhoAmIRequest\x1a!.sensory.api.oauth.WhoAmIResponse\"\x00\x12[\n\x0cGetPublicKey\x12#.sensory.api.oauth.PublicKeyRequest\x1a$.sensory.api.oauth.PublicKeyResponse\"\x00\x42l\n\x19\x61i.sensorycloud.api.oauthB\x14SensoryApiOauthProtoP\x01Z7gitlab.com/sensory-cloud/server/titan.git/pkg/api/oauthb\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,common_dot_common__pb2.DESCRIPTOR,])



_SIGNTOKENREQUEST_TOKENSCOPE = _descriptor.EnumDescriptor(
  name='TokenScope',
  full_name='sensory.api.oauth.SignTokenRequest.TokenScope',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUPER_ADMIN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BILLING_ADMIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY_ADMIN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_SELF_VERIFY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=268,
  serialized_end=370,
)
_sym_db.RegisterEnumDescriptor(_SIGNTOKENREQUEST_TOKENSCOPE)


_TOKENREQUEST = _descriptor.Descriptor(
  name='TokenRequest',
  full_name='sensory.api.oauth.TokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='sensory.api.oauth.TokenRequest.clientId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='sensory.api.oauth.TokenRequest.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=144,
)


_SIGNTOKENREQUEST = _descriptor.Descriptor(
  name='SignTokenRequest',
  full_name='sensory.api.oauth.SignTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='sensory.api.oauth.SignTokenRequest.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='sensory.api.oauth.SignTokenRequest.scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNTOKENREQUEST_TOKENSCOPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=370,
)


_WHOAMIREQUEST = _descriptor.Descriptor(
  name='WhoAmIRequest',
  full_name='sensory.api.oauth.WhoAmIRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=387,
)


_WHOAMIRESPONSE = _descriptor.Descriptor(
  name='WhoAmIResponse',
  full_name='sensory.api.oauth.WhoAmIResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='sensory.api.oauth.WhoAmIResponse.clientId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenantId', full_name='sensory.api.oauth.WhoAmIResponse.tenantId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=441,
)


_PUBLICKEYREQUEST = _descriptor.Descriptor(
  name='PublicKeyRequest',
  full_name='sensory.api.oauth.PublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyId', full_name='sensory.api.oauth.PublicKeyRequest.keyId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=486,
)


_PUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='PublicKeyResponse',
  full_name='sensory.api.oauth.PublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publicKey', full_name='sensory.api.oauth.PublicKeyResponse.publicKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyType', full_name='sensory.api.oauth.PublicKeyResponse.keyType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=572,
)

_SIGNTOKENREQUEST.fields_by_name['scope'].enum_type = _SIGNTOKENREQUEST_TOKENSCOPE
_SIGNTOKENREQUEST_TOKENSCOPE.containing_type = _SIGNTOKENREQUEST
_PUBLICKEYRESPONSE.fields_by_name['keyType'].enum_type = common_dot_common__pb2._KEYTYPE
DESCRIPTOR.message_types_by_name['TokenRequest'] = _TOKENREQUEST
DESCRIPTOR.message_types_by_name['SignTokenRequest'] = _SIGNTOKENREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIResponse'] = _WHOAMIRESPONSE
DESCRIPTOR.message_types_by_name['PublicKeyRequest'] = _PUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['PublicKeyResponse'] = _PUBLICKEYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenRequest = _reflection.GeneratedProtocolMessageType('TokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOKENREQUEST,
  '__module__' : 'oauth.oauth_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.oauth.TokenRequest)
  })
_sym_db.RegisterMessage(TokenRequest)

SignTokenRequest = _reflection.GeneratedProtocolMessageType('SignTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNTOKENREQUEST,
  '__module__' : 'oauth.oauth_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.oauth.SignTokenRequest)
  })
_sym_db.RegisterMessage(SignTokenRequest)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType('WhoAmIRequest', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIREQUEST,
  '__module__' : 'oauth.oauth_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.oauth.WhoAmIRequest)
  })
_sym_db.RegisterMessage(WhoAmIRequest)

WhoAmIResponse = _reflection.GeneratedProtocolMessageType('WhoAmIResponse', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIRESPONSE,
  '__module__' : 'oauth.oauth_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.oauth.WhoAmIResponse)
  })
_sym_db.RegisterMessage(WhoAmIResponse)

PublicKeyRequest = _reflection.GeneratedProtocolMessageType('PublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEYREQUEST,
  '__module__' : 'oauth.oauth_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.oauth.PublicKeyRequest)
  })
_sym_db.RegisterMessage(PublicKeyRequest)

PublicKeyResponse = _reflection.GeneratedProtocolMessageType('PublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEYRESPONSE,
  '__module__' : 'oauth.oauth_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.oauth.PublicKeyResponse)
  })
_sym_db.RegisterMessage(PublicKeyResponse)


DESCRIPTOR._options = None
_TOKENREQUEST.fields_by_name['clientId']._options = None
_SIGNTOKENREQUEST.fields_by_name['subject']._options = None
_SIGNTOKENREQUEST.fields_by_name['scope']._options = None
_PUBLICKEYREQUEST.fields_by_name['keyId']._options = None

_OAUTHSERVICE = _descriptor.ServiceDescriptor(
  name='OauthService',
  full_name='sensory.api.oauth.OauthService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=575,
  serialized_end=935,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetToken',
    full_name='sensory.api.oauth.OauthService.GetToken',
    index=0,
    containing_service=None,
    input_type=_TOKENREQUEST,
    output_type=common_dot_common__pb2._TOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignToken',
    full_name='sensory.api.oauth.OauthService.SignToken',
    index=1,
    containing_service=None,
    input_type=_SIGNTOKENREQUEST,
    output_type=common_dot_common__pb2._TOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWhoAmI',
    full_name='sensory.api.oauth.OauthService.GetWhoAmI',
    index=2,
    containing_service=None,
    input_type=_WHOAMIREQUEST,
    output_type=_WHOAMIRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicKey',
    full_name='sensory.api.oauth.OauthService.GetPublicKey',
    index=3,
    containing_service=None,
    input_type=_PUBLICKEYREQUEST,
    output_type=_PUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OAUTHSERVICE)

DESCRIPTOR.services_by_name['OauthService'] = _OAUTHSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from sensory_cloud.generated.v1.event import event_pb2 as v1_dot_event_dot_event__pb2


class EventServiceStub(object):
    """Service to publish events to the cloud
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PublishUsageEvents = channel.unary_unary(
                '/sensory.api.v1.event.EventService/PublishUsageEvents',
                request_serializer=v1_dot_event_dot_event__pb2.PublishUsageEventsRequest.SerializeToString,
                response_deserializer=v1_dot_event_dot_event__pb2.PublishUsageEventsResponse.FromString,
                )
        self.GetUsageEventList = channel.unary_unary(
                '/sensory.api.v1.event.EventService/GetUsageEventList',
                request_serializer=v1_dot_event_dot_event__pb2.UsageEventListRequest.SerializeToString,
                response_deserializer=v1_dot_event_dot_event__pb2.UsageEventListResponse.FromString,
                )
        self.GetUsageEventSummary = channel.unary_unary(
                '/sensory.api.v1.event.EventService/GetUsageEventSummary',
                request_serializer=v1_dot_event_dot_event__pb2.UsageEventListRequest.SerializeToString,
                response_deserializer=v1_dot_event_dot_event__pb2.UsageEventSummary.FromString,
                )
        self.GetGlobalUsageSummary = channel.unary_unary(
                '/sensory.api.v1.event.EventService/GetGlobalUsageSummary',
                request_serializer=v1_dot_event_dot_event__pb2.GlobalEventSummaryRequest.SerializeToString,
                response_deserializer=v1_dot_event_dot_event__pb2.UsageEventSummary.FromString,
                )


class EventServiceServicer(object):
    """Service to publish events to the cloud
    """

    def PublishUsageEvents(self, request, context):
        """Publishes a list of usage event to the cloud
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsageEventList(self, request, context):
        """Obtains a list of events given the filter criteria
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsageEventSummary(self, request, context):
        """Obtains a summary of events given the filter critieria
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGlobalUsageSummary(self, request, context):
        """Obtains a usage summary of events across all specified tenants
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PublishUsageEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishUsageEvents,
                    request_deserializer=v1_dot_event_dot_event__pb2.PublishUsageEventsRequest.FromString,
                    response_serializer=v1_dot_event_dot_event__pb2.PublishUsageEventsResponse.SerializeToString,
            ),
            'GetUsageEventList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsageEventList,
                    request_deserializer=v1_dot_event_dot_event__pb2.UsageEventListRequest.FromString,
                    response_serializer=v1_dot_event_dot_event__pb2.UsageEventListResponse.SerializeToString,
            ),
            'GetUsageEventSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsageEventSummary,
                    request_deserializer=v1_dot_event_dot_event__pb2.UsageEventListRequest.FromString,
                    response_serializer=v1_dot_event_dot_event__pb2.UsageEventSummary.SerializeToString,
            ),
            'GetGlobalUsageSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGlobalUsageSummary,
                    request_deserializer=v1_dot_event_dot_event__pb2.GlobalEventSummaryRequest.FromString,
                    response_serializer=v1_dot_event_dot_event__pb2.UsageEventSummary.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.event.EventService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventService(object):
    """Service to publish events to the cloud
    """

    @staticmethod
    def PublishUsageEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.event.EventService/PublishUsageEvents',
            v1_dot_event_dot_event__pb2.PublishUsageEventsRequest.SerializeToString,
            v1_dot_event_dot_event__pb2.PublishUsageEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUsageEventList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.event.EventService/GetUsageEventList',
            v1_dot_event_dot_event__pb2.UsageEventListRequest.SerializeToString,
            v1_dot_event_dot_event__pb2.UsageEventListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUsageEventSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.event.EventService/GetUsageEventSummary',
            v1_dot_event_dot_event__pb2.UsageEventListRequest.SerializeToString,
            v1_dot_event_dot_event__pb2.UsageEventSummary.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGlobalUsageSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.event.EventService/GetGlobalUsageSummary',
            v1_dot_event_dot_event__pb2.GlobalEventSummaryRequest.SerializeToString,
            v1_dot_event_dot_event__pb2.UsageEventSummary.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from sensory_cloud.generated.v1.management import device_pb2 as v1_dot_management_dot_device__pb2


class DeviceServiceStub(object):
    """Service to manage Devices in the database
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EnrollDevice = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/EnrollDevice',
                request_serializer=v1_dot_management_dot_device__pb2.EnrollDeviceRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
                )
        self.RenewDeviceCredential = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/RenewDeviceCredential',
                request_serializer=v1_dot_management_dot_device__pb2.RenewDeviceCredentialRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
                )
        self.GetWhoAmI = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/GetWhoAmI',
                request_serializer=v1_dot_management_dot_device__pb2.DeviceGetWhoAmIRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
                )
        self.GetDevice = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/GetDevice',
                request_serializer=v1_dot_management_dot_device__pb2.DeviceRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.GetDeviceResponse.FromString,
                )
        self.GetDevices = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/GetDevices',
                request_serializer=v1_dot_management_dot_device__pb2.GetDevicesRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.DeviceListResponse.FromString,
                )
        self.UpdateDevice = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/UpdateDevice',
                request_serializer=v1_dot_management_dot_device__pb2.UpdateDeviceRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
                )
        self.DeleteDevice = channel.unary_unary(
                '/sensory.api.v1.management.DeviceService/DeleteDevice',
                request_serializer=v1_dot_management_dot_device__pb2.DeviceRequest.SerializeToString,
                response_deserializer=v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
                )


class DeviceServiceServicer(object):
    """Service to manage Devices in the database
    """

    def EnrollDevice(self, request, context):
        """Create a new device in the database
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenewDeviceCredential(self, request, context):
        """Renew a device's credential, which links the device to a key in the database.
        This endpoint can be used to assign a new credential to a device if the old credential has expired.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWhoAmI(self, request, context):
        """Allows a device to fetch information about itself
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevice(self, request, context):
        """Returns device information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevices(self, request, context):
        """Returns a list of devices associated with the given userId
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDevice(self, request, context):
        """Allows the name of a device to be updated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDevice(self, request, context):
        """Allows a device to be deleted
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EnrollDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.EnrollDevice,
                    request_deserializer=v1_dot_management_dot_device__pb2.EnrollDeviceRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.DeviceResponse.SerializeToString,
            ),
            'RenewDeviceCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.RenewDeviceCredential,
                    request_deserializer=v1_dot_management_dot_device__pb2.RenewDeviceCredentialRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.DeviceResponse.SerializeToString,
            ),
            'GetWhoAmI': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWhoAmI,
                    request_deserializer=v1_dot_management_dot_device__pb2.DeviceGetWhoAmIRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.DeviceResponse.SerializeToString,
            ),
            'GetDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevice,
                    request_deserializer=v1_dot_management_dot_device__pb2.DeviceRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.GetDeviceResponse.SerializeToString,
            ),
            'GetDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevices,
                    request_deserializer=v1_dot_management_dot_device__pb2.GetDevicesRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.DeviceListResponse.SerializeToString,
            ),
            'UpdateDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDevice,
                    request_deserializer=v1_dot_management_dot_device__pb2.UpdateDeviceRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.DeviceResponse.SerializeToString,
            ),
            'DeleteDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDevice,
                    request_deserializer=v1_dot_management_dot_device__pb2.DeviceRequest.FromString,
                    response_serializer=v1_dot_management_dot_device__pb2.DeviceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.management.DeviceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeviceService(object):
    """Service to manage Devices in the database
    """

    @staticmethod
    def EnrollDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/EnrollDevice',
            v1_dot_management_dot_device__pb2.EnrollDeviceRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenewDeviceCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/RenewDeviceCredential',
            v1_dot_management_dot_device__pb2.RenewDeviceCredentialRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWhoAmI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/GetWhoAmI',
            v1_dot_management_dot_device__pb2.DeviceGetWhoAmIRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/GetDevice',
            v1_dot_management_dot_device__pb2.DeviceRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.GetDeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/GetDevices',
            v1_dot_management_dot_device__pb2.GetDevicesRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.DeviceListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/UpdateDevice',
            v1_dot_management_dot_device__pb2.UpdateDeviceRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.management.DeviceService/DeleteDevice',
            v1_dot_management_dot_device__pb2.DeviceRequest.SerializeToString,
            v1_dot_management_dot_device__pb2.DeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import unittest
import datetime

from sensory_cloud.token_manager import TokenManager, OAuthToken
from sensory_cloud.services.oauth_service import OauthClient, IOauthService

import sensory_cloud.generated.v1.management.device_pb2 as device_pb2


class TestOauthService(IOauthService):
    def __init__(self, oauth_token: OAuthToken):
        self._oauth_token: OAuthToken = oauth_token
        self._get_token_was_called: int = 0

    @property
    def get_token_was_called(self) -> int:
        return self._get_token_was_called

    @property
    def oauth_token(self):
        return self._oauth_token

    @oauth_token.setter
    def oauth_token(self, value: OAuthToken):
        self._oauth_token = value

    def generate_credentials(self) -> OauthClient:
        raise NotImplementedError()

    def get_token(self) -> OAuthToken:
        self._get_token_was_called += 1
        return self._oauth_token

    def register(
        self, device_id: str, device_name: str, credential: str
    ) -> device_pb2.DeviceResponse:
        raise NotImplementedError


class TokenManagerTest(unittest.TestCase):
    def test_get_token(self):
        oauth_token: OAuthToken = OAuthToken(
            token="my-token", expires=datetime.datetime.utcnow()
        )
        oauth_service: TestOauthService = TestOauthService(oauth_token=oauth_token)

        token_manager: TokenManager = TokenManager(oauth_service=oauth_service)

        token: str = token_manager.get_token()
        self.assertEqual(
            token,
            oauth_service.oauth_token.token,
            "The token returned should be correct",
        )
        self.assertEqual(
            oauth_service.get_token_was_called,
            1,
            "OAuth service should be called if no token is populated",
        )

        oauth_service.oauth_token = OAuthToken(
            token="another-token", expires=datetime.datetime.utcnow()
        )

        token: str = token_manager.get_token()
        self.assertEqual(
            token,
            oauth_service.oauth_token.token,
            "The token returned should be correct",
        )
        self.assertEqual(
            oauth_service.get_token_was_called, 2, "OAuth service should not be called"
        )

        oauth_service.oauth_token = OAuthToken(
            token="a-final-token",
            expires=datetime.datetime.utcnow() + datetime.timedelta(days=1),
        )

        token: str = token_manager.get_token()
        self.assertEqual(
            token,
            oauth_service.oauth_token.token,
            "The token returned should be correct",
        )
        self.assertEqual(
            oauth_service.get_token_was_called,
            3,
            "OAuth service should be called if token is expired",
        )

        token: str = token_manager.get_token()
        self.assertEqual(
            token,
            oauth_service.oauth_token.token,
            "The token returned should be correct",
        )
        self.assertEqual(
            oauth_service.get_token_was_called,
            3,
            "OAuth service should be called if token is expired",
        )

    def test_get_authorization_metadata(self):
        oauth_token: OAuthToken = OAuthToken(
            token="my-token", expires=datetime.datetime.utcnow()
        )
        oauth_service: TestOauthService = TestOauthService(oauth_token=oauth_token)

        token_manager: TokenManager = TokenManager(oauth_service=oauth_service)

        token_manager.get_authorization_metadata()

        self.assertEqual(
            oauth_service.get_token_was_called,
            1,
            "OAuth service should be called if no token is populated",
        )


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/file/file.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/file/file.proto',
  package='sensory.api.v1.file',
  syntax='proto3',
  serialized_options=b'\n\033ai.sensorycloud.api.v1.fileB\025SensoryApiV1FileProtoP\001Z9gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/file',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12v1/file/file.proto\x12\x13sensory.api.v1.file\x1a\x17validate/validate.proto\"u\n\x0b\x46ileRequest\x12\x18\n\x04\x66ile\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x0f\x12<\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32*.sensory.api.v1.file.VersionedFileCategory\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\x95\x01\n\x0c\x46ileResponse\x12-\n\x04info\x18\x01 \x01(\x0b\x32\x1d.sensory.api.v1.file.FileInfoH\x00\x12/\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\x1e.sensory.api.v1.file.FileChunkH\x00\x12\x10\n\x08\x63omplete\x18\x03 \x01(\x08\x42\x13\n\x11streamingResponse\"^\n\x12\x46ileCatalogRequest\x12H\n\ncategories\x18\x01 \x03(\x0b\x32*.sensory.api.v1.file.VersionedFileCategoryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\".\n\x1a\x46ileCompleteCatalogRequest\x12\x10\n\x08tenantId\x18\x01 \x01(\t\"H\n\x13\x46ileCatalogResponse\x12\x31\n\x07\x63\x61talog\x18\x01 \x03(\x0b\x32 .sensory.api.v1.file.FileCatalog\"*\n\tFileChunk\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"q\n\x08\x46ileInfo\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x62solutePath\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\x13\n\x0b\x63ontentType\x18\x04 \x01(\t\x12\x0c\n\x04hash\x18\x05 \x01(\t\x12\x10\n\x08tenantId\x18\x06 \x01(\t\"y\n\x0b\x46ileCatalog\x12,\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1d.sensory.api.v1.file.FileInfo\x12<\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32*.sensory.api.v1.file.VersionedFileCategory\"g\n\x15VersionedFileCategory\x12=\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32!.sensory.api.v1.file.FileCategoryB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t*K\n\x0c\x46ileCategory\x12\x0e\n\nTSSV_MODEL\x10\x00\x12\x0f\n\x0b\x41TLAS_MODEL\x10\x01\x12\r\n\tTNL_MODEL\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x64\x32\xff\x02\n\x04\x46ile\x12L\n\x07GetInfo\x12 .sensory.api.v1.file.FileRequest\x1a\x1d.sensory.api.v1.file.FileInfo\"\x00\x12\x61\n\nGetCatalog\x12\'.sensory.api.v1.file.FileCatalogRequest\x1a(.sensory.api.v1.file.FileCatalogResponse\"\x00\x12q\n\x12GetCompleteCatalog\x12/.sensory.api.v1.file.FileCompleteCatalogRequest\x1a(.sensory.api.v1.file.FileCatalogResponse\"\x00\x12S\n\x08\x44ownload\x12 .sensory.api.v1.file.FileRequest\x1a!.sensory.api.v1.file.FileResponse\"\x00\x30\x01\x42q\n\x1b\x61i.sensorycloud.api.v1.fileB\x15SensoryApiV1FileProtoP\x01Z9gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/fileb\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,])

_FILECATEGORY = _descriptor.EnumDescriptor(
  name='FileCategory',
  full_name='sensory.api.v1.file.FileCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TSSV_MODEL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ATLAS_MODEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TNL_MODEL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=3, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=944,
  serialized_end=1019,
)
_sym_db.RegisterEnumDescriptor(_FILECATEGORY)

FileCategory = enum_type_wrapper.EnumTypeWrapper(_FILECATEGORY)
TSSV_MODEL = 0
ATLAS_MODEL = 1
TNL_MODEL = 2
UNKNOWN = 100



_FILEREQUEST = _descriptor.Descriptor(
  name='FileRequest',
  full_name='sensory.api.v1.file.FileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='sensory.api.v1.file.FileRequest.file', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\017', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='sensory.api.v1.file.FileRequest.category', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='sensory.api.v1.file.FileRequest.offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=185,
)


_FILERESPONSE = _descriptor.Descriptor(
  name='FileResponse',
  full_name='sensory.api.v1.file.FileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='sensory.api.v1.file.FileResponse.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='sensory.api.v1.file.FileResponse.chunk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete', full_name='sensory.api.v1.file.FileResponse.complete', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingResponse', full_name='sensory.api.v1.file.FileResponse.streamingResponse',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=188,
  serialized_end=337,
)


_FILECATALOGREQUEST = _descriptor.Descriptor(
  name='FileCatalogRequest',
  full_name='sensory.api.v1.file.FileCatalogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='categories', full_name='sensory.api.v1.file.FileCatalogRequest.categories', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=433,
)


_FILECOMPLETECATALOGREQUEST = _descriptor.Descriptor(
  name='FileCompleteCatalogRequest',
  full_name='sensory.api.v1.file.FileCompleteCatalogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantId', full_name='sensory.api.v1.file.FileCompleteCatalogRequest.tenantId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=481,
)


_FILECATALOGRESPONSE = _descriptor.Descriptor(
  name='FileCatalogResponse',
  full_name='sensory.api.v1.file.FileCatalogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='catalog', full_name='sensory.api.v1.file.FileCatalogResponse.catalog', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=555,
)


_FILECHUNK = _descriptor.Descriptor(
  name='FileChunk',
  full_name='sensory.api.v1.file.FileChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes', full_name='sensory.api.v1.file.FileChunk.bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='sensory.api.v1.file.FileChunk.offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=557,
  serialized_end=599,
)


_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='sensory.api.v1.file.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='sensory.api.v1.file.FileInfo.file', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolutePath', full_name='sensory.api.v1.file.FileInfo.absolutePath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='sensory.api.v1.file.FileInfo.size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contentType', full_name='sensory.api.v1.file.FileInfo.contentType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='sensory.api.v1.file.FileInfo.hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenantId', full_name='sensory.api.v1.file.FileInfo.tenantId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=714,
)


_FILECATALOG = _descriptor.Descriptor(
  name='FileCatalog',
  full_name='sensory.api.v1.file.FileCatalog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='sensory.api.v1.file.FileCatalog.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='sensory.api.v1.file.FileCatalog.category', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=837,
)


_VERSIONEDFILECATEGORY = _descriptor.Descriptor(
  name='VersionedFileCategory',
  full_name='sensory.api.v1.file.VersionedFileCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='sensory.api.v1.file.VersionedFileCategory.category', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='sensory.api.v1.file.VersionedFileCategory.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=942,
)

_FILEREQUEST.fields_by_name['category'].message_type = _VERSIONEDFILECATEGORY
_FILERESPONSE.fields_by_name['info'].message_type = _FILEINFO
_FILERESPONSE.fields_by_name['chunk'].message_type = _FILECHUNK
_FILERESPONSE.oneofs_by_name['streamingResponse'].fields.append(
  _FILERESPONSE.fields_by_name['info'])
_FILERESPONSE.fields_by_name['info'].containing_oneof = _FILERESPONSE.oneofs_by_name['streamingResponse']
_FILERESPONSE.oneofs_by_name['streamingResponse'].fields.append(
  _FILERESPONSE.fields_by_name['chunk'])
_FILERESPONSE.fields_by_name['chunk'].containing_oneof = _FILERESPONSE.oneofs_by_name['streamingResponse']
_FILECATALOGREQUEST.fields_by_name['categories'].message_type = _VERSIONEDFILECATEGORY
_FILECATALOGRESPONSE.fields_by_name['catalog'].message_type = _FILECATALOG
_FILECATALOG.fields_by_name['files'].message_type = _FILEINFO
_FILECATALOG.fields_by_name['category'].message_type = _VERSIONEDFILECATEGORY
_VERSIONEDFILECATEGORY.fields_by_name['category'].enum_type = _FILECATEGORY
DESCRIPTOR.message_types_by_name['FileRequest'] = _FILEREQUEST
DESCRIPTOR.message_types_by_name['FileResponse'] = _FILERESPONSE
DESCRIPTOR.message_types_by_name['FileCatalogRequest'] = _FILECATALOGREQUEST
DESCRIPTOR.message_types_by_name['FileCompleteCatalogRequest'] = _FILECOMPLETECATALOGREQUEST
DESCRIPTOR.message_types_by_name['FileCatalogResponse'] = _FILECATALOGRESPONSE
DESCRIPTOR.message_types_by_name['FileChunk'] = _FILECHUNK
DESCRIPTOR.message_types_by_name['FileInfo'] = _FILEINFO
DESCRIPTOR.message_types_by_name['FileCatalog'] = _FILECATALOG
DESCRIPTOR.message_types_by_name['VersionedFileCategory'] = _VERSIONEDFILECATEGORY
DESCRIPTOR.enum_types_by_name['FileCategory'] = _FILECATEGORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FileRequest = _reflection.GeneratedProtocolMessageType('FileRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILEREQUEST,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileRequest)
  })
_sym_db.RegisterMessage(FileRequest)

FileResponse = _reflection.GeneratedProtocolMessageType('FileResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILERESPONSE,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileResponse)
  })
_sym_db.RegisterMessage(FileResponse)

FileCatalogRequest = _reflection.GeneratedProtocolMessageType('FileCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILECATALOGREQUEST,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileCatalogRequest)
  })
_sym_db.RegisterMessage(FileCatalogRequest)

FileCompleteCatalogRequest = _reflection.GeneratedProtocolMessageType('FileCompleteCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILECOMPLETECATALOGREQUEST,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileCompleteCatalogRequest)
  })
_sym_db.RegisterMessage(FileCompleteCatalogRequest)

FileCatalogResponse = _reflection.GeneratedProtocolMessageType('FileCatalogResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILECATALOGRESPONSE,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileCatalogResponse)
  })
_sym_db.RegisterMessage(FileCatalogResponse)

FileChunk = _reflection.GeneratedProtocolMessageType('FileChunk', (_message.Message,), {
  'DESCRIPTOR' : _FILECHUNK,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileChunk)
  })
_sym_db.RegisterMessage(FileChunk)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

FileCatalog = _reflection.GeneratedProtocolMessageType('FileCatalog', (_message.Message,), {
  'DESCRIPTOR' : _FILECATALOG,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.FileCatalog)
  })
_sym_db.RegisterMessage(FileCatalog)

VersionedFileCategory = _reflection.GeneratedProtocolMessageType('VersionedFileCategory', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONEDFILECATEGORY,
  '__module__' : 'v1.file.file_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.file.VersionedFileCategory)
  })
_sym_db.RegisterMessage(VersionedFileCategory)


DESCRIPTOR._options = None
_FILEREQUEST.fields_by_name['file']._options = None
_FILECATALOGREQUEST.fields_by_name['categories']._options = None
_VERSIONEDFILECATEGORY.fields_by_name['category']._options = None

_FILE = _descriptor.ServiceDescriptor(
  name='File',
  full_name='sensory.api.v1.file.File',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1022,
  serialized_end=1405,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInfo',
    full_name='sensory.api.v1.file.File.GetInfo',
    index=0,
    containing_service=None,
    input_type=_FILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCatalog',
    full_name='sensory.api.v1.file.File.GetCatalog',
    index=1,
    containing_service=None,
    input_type=_FILECATALOGREQUEST,
    output_type=_FILECATALOGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCompleteCatalog',
    full_name='sensory.api.v1.file.File.GetCompleteCatalog',
    index=2,
    containing_service=None,
    input_type=_FILECOMPLETECATALOGREQUEST,
    output_type=_FILECATALOGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='sensory.api.v1.file.File.Download',
    index=3,
    containing_service=None,
    input_type=_FILEREQUEST,
    output_type=_FILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FILE)

DESCRIPTOR.services_by_name['File'] = _FILE

# @@protoc_insertion_point(module_scope)



import unittest
import typing

from sensory_cloud.services.crypto_service import CryptoService


class CryptoServiceTest(unittest.TestCase):
    def test_get_secure_random_string(self):
        test_num: int = 100
        random_strings: typing.List[str] = []

        for i in range(test_num):
            random_string: str = CryptoService().get_secure_random_string(
                length=test_num + 1
            )
            self.assertEqual(len(random_string), test_num + 1)
            random_strings.append(random_string)

        self.assertEqual(len(random_strings), test_num)


if __name__ == "__main__":
    unittest.main()
